pub trait DisplayFullErrorExt: Error + Sealed {
// Provided method
fn display_full(&self) -> DisplayFullError<'_, Self> { ... }
}Expand description
Extension trait providing convenience methods on errors.
This trait provides a blanket implementation for all types implementing the standard Error trait.
Provided Methods
Sourcefn display_full(&self) -> DisplayFullError<'_, Self>
fn display_full(&self) -> DisplayFullError<'_, Self>
Get a reference to this error wrapped in a DisplayFullError formatter, to display the error with all its sources.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".